# SPDX-FileCopyrightText: 2019 Free Software Foundation Europe e.V.
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""Entry module for reuse."""

if __name__ == "__main__":
    from ._main import main

    main()
